@@ -34,18 +34,18 @@ from google.auth.exceptions import DefaultCredentialsError
 from google.cloud import storage as gcp_storage
 from google.oauth2 import service_account
 
-from epl.protobuf import stac_service_pb2_grpc
-from epl.protobuf.geometry_pb2 import GeometryData, SpatialReferenceData, EnvelopeData
-from epl.protobuf.query_pb2 import TimestampField, FloatField, StringField, UInt32Field
-from epl.protobuf.stac_pb2 import StacRequest, StacItem, Asset, LandsatRequest, Eo, EoRequest, Mosaic, MosaicRequest, \
-    DatetimeRange
+from epl.protobuf.v1 import stac_service_pb2_grpc
+from epl.protobuf.v1.geometry_pb2 import GeometryData, ProjectionData, EnvelopeData
+from epl.protobuf.v1.query_pb2 import TimestampFilter, FloatFilter, StringFilter, UInt32Filter
+from epl.protobuf.v1.stac_pb2 import StacRequest, StacItem, Asset, LandsatRequest, Eo, EoRequest, Mosaic, \
+    MosaicRequest, DatetimeRange, View, ViewRequest
 
 __all__ = [
     'stac_service', 'url_to_channel', 'STAC_SERVICE',
-    'EoRequest', 'StacRequest', 'LandsatRequest', 'MosaicRequest',
-    'GeometryData', 'SpatialReferenceData', 'EnvelopeData',
-    'FloatField', 'TimestampField', 'StringField', 'UInt32Field',
-    'StacItem', 'Asset', 'Eo', 'Mosaic', 'DatetimeRange',
+    'EoRequest', 'StacRequest', 'LandsatRequest', 'MosaicRequest', 'ViewRequest',
+    'GeometryData', 'ProjectionData', 'EnvelopeData',
+    'FloatFilter', 'TimestampFilter', 'StringFilter', 'UInt32Filter',
+    'StacItem', 'Asset', 'Eo', 'View', 'Mosaic', 'DatetimeRange',
     'gcs_storage_client',
     'AUTH0_TENANT', 'API_AUDIENCE', 'ISSUER', 'bearer_auth'
 ]
@@ -256,9 +256,9 @@ class __BearerAuth:
 
     def auth_header(self):
         if (self.expiry - time.time()) < TOKEN_REFRESH_THRESHOLD:
-            print("re-authorize bearer expiration {0}, threshold (in seconds) {1}"
-                  .format(self.expiry, time.time(), TOKEN_REFRESH_THRESHOLD))
             self.authorize()
+            print("fetching new authorization in {0} seconds".format(
+                round(self.expiry - time.time() - TOKEN_REFRESH_THRESHOLD)))
         return "Bearer {token}".format(token=self._token)
 
     def authorize(self, backoff: int = 0):
@@ -280,27 +280,29 @@ class __BearerAuth:
             conn.request("POST", "/oauth/token", json.dumps(post_body), headers)
             res = conn.getresponse()
 
-            if res.code != 200:
-                warnings.warn("authentication error code {0}".format(res.code))
+            # evaluate codes first.
+            # then if response is empty, HTTPResponse method for read returns b"" which will be zero in length
+            res_body = res.read()
+            if (res.getcode() != 200 and res.getcode() != 201) or len(res_body) == 0:
+                warnings.warn("authentication failed with code {0}".format(res.getcode()))
 
-            res_body = json.loads(res.read().decode("utf-8"))
-            if "error" in res_body:
-                warnings.warn("authentication failed with error '{0}' and message '{1}'"
-                              .format(res_body["error"], res_body["error_description"]))
+                # TODO make this non-recursive
                 self.retry(backoff)
                 return
 
+            res_json = json.loads(res_body.decode("utf-8"))
+
             self.retries = 0
-            self._expiry = now + int(res_body["expires_in"])
-            self._token = res_body["access_token"]
-        except json.JSONDecodeError:
-            warnings.warn("failed to decode authentication json token")
-            self._expiry = 0
-            self._token = {}
+            self._expiry = now + int(res_json["expires_in"])
+            self._token = res_json["access_token"]
+        except json.JSONDecodeError as je:
+            warnings.warn("failed to decode authentication json token with error: {}".format(je))
+            self.retry(backoff)
+            return
         except BaseException as be:
             warnings.warn("failed to connect to authorization service with error: {0}".format(be))
-            self._expiry = 0
-            self._token = {}
+            self.retry(backoff)
+            return
 
     @property
     def expiry(self):
@@ -310,7 +312,7 @@ class __BearerAuth:
         """Retry authorization request, with exponential backoff"""
         self.retries += 1
         backoff = min(2 if timeout == 0 else timeout * 2, MAX_TOKEN_REFRESH_BACKOFF)
-        TOKEN_REFRESH_SCHEDULER.enter(backoff, 1, self.authorize, argument=backoff)
+        TOKEN_REFRESH_SCHEDULER.enter(backoff, 1, self.authorize, argument=[backoff])
         TOKEN_REFRESH_SCHEDULER.run()
 
 
